pub enum RectSpec {
Absolute(LayoutRect),
Percent {
x: u16,
y: u16,
width: u16,
height: u16,
},
}Expand description
A rectangle specification that can be either absolute or percentage-based.
Percentage values are relative to bounds at resolution time.
Variants
Absolute(LayoutRect)
Fixed pixel/cell position and size.
Percent
Percentage of the bounding rectangle.
Implementations
Sourceimpl RectSpec
impl RectSpec
Sourcepub fn resolve(&self, bounds: LayoutRect) -> LayoutRect
pub fn resolve(&self, bounds: LayoutRect) -> LayoutRect
Resolve this spec against bounds to produce a concrete LayoutRect.