pub fn detect_corner_snap(
col: u16,
row: u16,
managed_area: LayoutRect,
sensitivity: u16,
) -> Option<InsertPosition>Expand description
Detect a corner snap when the cursor is simultaneously within sensitivity
of both an X edge and a Y edge. Uses saturating arithmetic exclusively.